@@ -166,7 +166,7 @@ std::string Config::_defaults =
   "color=on                                       # Enable color\n"
 #if defined(LINUX) || defined(DARWIN)
   "\n"
-  "rule.precedence.color=deleted,completed,active,keyword.,tag.,uda.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,pri.\n"
+  "rule.precedence.color=deleted,completed,active,keyword.,tag.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,uda.\n"
   "\n"
   "# General decoration\n"
   "color.label=\n"
@@ -240,7 +240,7 @@ std::string Config::_defaults =
   "\n"
 #else
   "\n"
-  "rule.precedence.color=deleted,completed,active,keyword.,tag.,uda.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,pri.\n"
+  "rule.precedence.color=deleted,completed,active,keyword.,tag.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,uda.\n"
   "\n"
   "# General decoration\n"
   "color.label=\n"
@@ -329,7 +329,7 @@ std::string Config::_defaults =
   "# Here is the rule precedence order, highest to lowest.\n"
   "# Note that these are just the color rule names, without the leading 'color.'\n"
   "#      and any trailing '.value'.\n"
-  "rule.precedence.color=deleted,completed,active,keyword.,tag.,uda.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,pri.\n"
+  "rule.precedence.color=deleted,completed,active,keyword.,tag.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,uda.\n"
   "\n"
   "#default.project=foo                           # Default project for 'add' command\n"
   "#default.due=eom                               # Default due date for 'add' command\n"
@@ -342,6 +342,7 @@ std::string Config::_defaults =
   "list.all.tags=no                               # Include old tag names in 'tags' command\n"
   "print.empty.columns=no                         # Print columns which have no data for any task\n"
   "debug=no                                       # Display diagnostics\n"
+  "obfuscate=no                                   # Obfuscate data for error reporting\n"
   "fontunderline=yes                              # Uses underlines rather than -------\n"
   "shell.prompt=task>                             # Prompt used by the shell command\n"
   "\n"
