@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2014, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -37,7 +36,7 @@ Context context;
 ////////////////////////////////////////////////////////////////////////////////
 int main (int argc, char** argv)
 {
-  UnitTest t (209);
+  UnitTest t (211);
 
   // Ensure environment has no influence.
   unsetenv ("TASKDATA");
@@ -367,9 +366,6 @@ int main (int argc, char** argv)
     t.notok (first.sameMonth (now), "1st not in same month as now");
     t.is (first.day (),   1, "1st day is 1");
 
-    Date FIRST ("1ST");
-    t.ok (FIRST == first, "1st == 1ST");
-
     Date later ("later");
     t.is (later.month (),   1, "later -> m = 1");
     t.is (later.day (),    18, "later -> d = 18");
@@ -442,6 +438,15 @@ int main (int argc, char** argv)
     t.is (Date::length ("J"), 3,  "length 'J' --> 3");
 
     t.is (Date::length (" "), 1, "length ' ' --> 1");
+
+    // Depletion requirement.
+    Date r30 ("Mon Jun 30 2014", "a b D Y", false, false);
+    t.is (r30.toString ("YMDHNS"), "20140630000000", "Depletion required on complex format with spaces");
+
+    std::string::size_type i = 0;
+    Date r31 ("Mon Jun 30 2014 xxx", i, "a b D Y", false, false);
+    t.is (r31.toString ("YMDHNS"), "20140630000000", "Depletion not required on complex format with spaces");
+    t.is ((int)i, 15,                                "Depletion not required on complex format with spaces, 15 chars");
   }
 
   catch (const std::string& e)
